@@ -11,7 +11,7 @@ from .common import User
 from .integration import Integration
 
 
-class GitToolName(str, Enum):
+class GitTool(str, Enum):
     """Enum for Git tool names."""
 
     LIST_BRANCHES_IN_REPO = "list_branches_in_repo"
@@ -26,8 +26,8 @@ class GitToolName(str, Enum):
     CREATE_PR_CHANGES_COMMENT = "create_pr_changes_comment"
 
 
-class CodeBaseToolName(str, Enum):
-    """Enum for Git tool names."""
+class CodeBaseTool(str, Enum):
+    """Enum for CodeBase tool names."""
 
     SONAR = "Sonar"
     SONAR_CLOUD = "Sonar"
@@ -38,15 +38,15 @@ class CodeBaseToolName(str, Enum):
     SEARCH_CODE_REPO_BY_PATH = "search_code_repo_by_path"
 
 
-class VcsToolName(str, Enum):
+class VcsTool(str, Enum):
     """Enum for VCS tool names."""
 
     GITLAB = "gitlab"
     GITHUB = "github"
 
 
-class CloudToolName(str, Enum):
-    """Enum for VCS tool names."""
+class CloudTool(str, Enum):
+    """Enum for Cloud tool names."""
 
     AWS = "AWS"
     GCP = "GCP"
@@ -54,11 +54,49 @@ class CloudToolName(str, Enum):
 
 
 class PluginToolName(str, Enum):
-    """Enum for VCS tool names."""
+    """Enum for Plugin tool names."""
 
     PLUGIN = "Plugin"
 
 
+class AzureDevOpsWikiTool(str, Enum):
+    """Enum for Azure DevOps Wiki tool names."""
+
+    GET_WIKI = "get_wiki"
+    GET_WIKI_PAGE_BY_PATH = "get_wiki_page_by_path"
+    GET_WIKI_PAGE_BY_ID = "get_wiki_page_by_id"
+    DELETE_WIKI_PAGE_BY_PATH = "delete_page_by_path"
+    DELETE_WIKI_PAGE_BY_ID = "delete_page_by_id"
+    MODIFY_WIKI_PAGE = "modify_wiki_page"
+    RENAME_WIKI_PAGE = "rename_wiki_page"
+
+
+class AzureDevOpsTestPlanTool(str, Enum):
+    """Enum for Azure DevOps Test Plan tool names."""
+
+    CREATE_TEST_PLAN = "create_test_plan"
+    DELETE_TEST_PLAN = "delete_test_plan"
+    GET_TEST_PLAN = "get_test_plan"
+    CREATE_TEST_SUITE = "create_test_suite"
+    DELETE_TEST_SUITE = "delete_test_suite"
+    GET_TEST_SUITE = "get_test_suite"
+    ADD_TEST_CASE = "add_test_case"
+    GET_TEST_CASE = "get_test_case"
+    GET_TEST_CASES = "get_test_cases"
+
+
+class AzureDevOpsWorkItemTool(str, Enum):
+    """Enum for Azure DevOps Work Item tool names."""
+
+    GET_WORK_ITEM = "get_work_item"
+    GET_COMMENTS = "get_comments"
+    GET_RELATION_TYPES = "get_relation_types"
+    SEARCH_WORK_ITEMS = "search_work_items"
+    CREATE_WORK_ITEM = "create_work_item"
+    UPDATE_WORK_ITEM = "update_work_item"
+    LINK_WORK_ITEMS = "link_work_items"
+
+
 class ResearchToolName(str, Enum):
     """Enum for Research tool names."""
 
@@ -70,6 +108,18 @@ class ResearchToolName(str, Enum):
     WEB_SCRAPPER = "web_scrapper"
 
 
+class NotificationTool(str, Enum):
+    """Enum for Notification tool names."""
+
+    EMAIL = "email"
+
+
+class ProjectManagementTool(str, Enum):
+    """Enum for Project Management tool names."""
+
+    JIRA = "jira"
+
+
 class ToolDetails(BaseModel):
     """Model for tool details."""
 
@@ -91,6 +141,11 @@ class Toolkit(str, Enum):
     CLOUD = "Cloud"
     PLUGIN = "Plugin"
     RESEARCH = "Research"
+    AZURE_DEVOPS_TEST_PLAN = "Azure DevOps Test Plan"
+    AZURE_DEVOPS_WORK_ITEM = "Azure DevOps Work Item"
+    AZURE_DEVOPS_WIKI = "Azure DevOps Wiki"
+    NOTIFICATION = "Notification"
+    PROJECT_MANAGEMENT = "Project Management"
 
 
 class ToolKitDetails(BaseModel):
